@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,13 +20,9 @@
 
 #include <QRegularExpression>
 
-ClawsMailSettings::ClawsMailSettings()
-{
-}
+ClawsMailSettings::ClawsMailSettings() = default;
 
-ClawsMailSettings::~ClawsMailSettings()
-{
-}
+ClawsMailSettings::~ClawsMailSettings() = default;
 
 void ClawsMailSettings::importSettings(const QString &filename, const QString &path)
 {
